@@ -10,7 +10,7 @@ class Carrot(tk.Canvas):
     def __init__(self, layout):
 
         self.__layout = layout
-        self.__bkg = "./default-bkg.png"
+        self.__bkg = "default-bkg.png"
         self.__width, self.__height = layout.get_dimensions()
         self.__border_width = 1
 
