@@ -13,7 +13,7 @@ class Layout(tk.Tk):
         super().__init__()
         print(os.getcwd)
         self.__title = "carrot app"
-        self.__icon = "./carrot-icon.ico"
+        self.__icon = "carrot-icon.ico"
         self.__width = int(self.winfo_screenwidth())
         self.__height = int(self.winfo_screenheight())
         self.__close_message = "Kill carrot?"
